package net.sf.r4h;

import java.io.Serializable;

/**
 * 
 * Provides page information such as page size and page number. Page numbers start from 1.
 * 
 * Can be used in environments(GWT,RMI,Web Services clients) without direct Hibernate dependencies.
 * 
 * The class is immutable and thread safe.
 * 
 * @author vitaly.se@gmail.com
 * 
 * @since 4.0.0
 * 
 */
public class Page implements Serializable {
	private static final long serialVersionUID = -3676283829117383648L;
	/**
	 * page number.
	 */
	private int number;
	/**
	 * page size.
	 */
	private int size;

	/**
	 * Needed for GWT RPC
	 */
	@SuppressWarnings("unused")
	private Page() {
		this(0, 0);
	}

	/**
	 * 
	 * @param number
	 *            page number starting from 1.
	 * @param size
	 *            page size must be not negative, can be 0 in this case nothing will be returned and the database won't be hit
	 */
	public Page(int number, int size) {
		if (number < 1) {
			throw new IllegalArgumentException("page number must be >= 1");
		}
		if (size < 0) {
			throw new IllegalArgumentException("page size must be >= 0 ");
		}
		this.number = number;
		this.size = size;
	}

	@Override
	public int hashCode() {
		final int prime = 31;
		int result = 1;
		result = prime * result + number;
		result = prime * result + size;
		return result;
	}

	@Override
	public boolean equals(Object obj) {
		if (this == obj)
			return true;
		if (obj == null)
			return false;
		if (getClass() != obj.getClass())
			return false;
		Page other = (Page) obj;
		if (number != other.number)
			return false;
		if (size != other.size)
			return false;
		return true;
	}

	public int getNumber() {
		return number;
	}

	public int getSize() {
		return size;
	}

}
