package net.sf.r4h;

import java.io.Serializable;

/**
 * 
 * Provides partition information such as first of first entity to return starting from 0 and maximum amount of entities to return.
 * 
 * Can be used in environments(GWT,RMI,Web Services clients) without direct Hibernate dependencies.
 * 
 * The class is immutable and thread safe.
 * 
 * @author vitaly.se@gmail.com
 * 
 * @since 4.1.1
 * 
 */
public class Partition implements Serializable {
	private static final long serialVersionUID = -3676283829117383648L;
	/**
	 * firs element to return counting from 0
	 */
	private int first;
	/**
	 * page max.
	 */
	private int max;

	/**
	 * Needed for GWT RPC
	 */
	@SuppressWarnings("unused")
	private Partition() {
		this(0, 0);
	}

	/**
	 * 
	 * @param first
	 *            page first starting from 1.
	 * @param max
	 *            page max must be not negative, can be 0 in this case nothing will be returned and the database won't be hit
	 */
	public Partition(int first, int max) {
		if (first < 0) {
			throw new IllegalArgumentException("first must be >= 0");
		}
		if (max < 0) {
			throw new IllegalArgumentException("max must be >= 0 ");
		}
		this.first = first;
		this.max = max;
	}

	@Override
	public int hashCode() {
		final int prime = 31;
		int result = 1;
		result = prime * result + first;
		result = prime * result + max;
		return result;
	}

	@Override
	public boolean equals(Object obj) {
		if (this == obj)
			return true;
		if (obj == null)
			return false;
		if (getClass() != obj.getClass())
			return false;
		Partition other = (Partition) obj;
		if (first != other.first)
			return false;
		if (max != other.max)
			return false;
		return true;
	}

	public int getFirst() {
		return first;
	}

	public int getMax() {
		return max;
	}

}
